==> epic4pre1.039.tar.gz: ircii-EPIC4pre1.039/include/term.h <==
/*
 * term.h: header file for term.c 
 *
 * Copyright 1990 Michael Sandrof
 * Copyright 1997 EPIC Software Labs
 * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
 */

#ifndef __term_h__
#define __term_h__

/* To get declaration of "current_screen" */
#include "screen.h"

extern	int	need_redraw;
extern	char	*CM, *DO, *CE, *CL, *CR, *NL, *SO, *SE, *US, 
		*UE, *MD, *ME, *BL, *MB;
extern	int	CO, LI, SG; 

/* 
 * This puts a character to the current target, whatever it is. 
 * All output everywhere should go thorugh this.
 * This does not mangle its output, so its suitable for outputting
 * escape sequences.
 */
#if !defined(WTERM_C) && !defined(WSERV_C)
#define current_ftarget (output_screen ? output_screen->fpout : stdout)

__inline__ 
static int putchar_x (int c) { return fputc((int) c, current_ftarget); }

__inline__
static void term_flush (void) { fflush(current_ftarget); }
#endif


#define tputs_x(s)			(tputs(s, 0, putchar_x))
#define term_underline_on()		(tputs_x(US))
#define term_underline_off()		(tputs_x(UE))
#define term_standout_on()		(tputs_x(SO))
#define term_standout_off()		(tputs_x(SE))
#define term_blink_on()			(tputs_x(MB))
#define term_clear_screen()		(tputs_x(CL))
#define term_move_cursor(c, r)		(tputs_x(tgoto(CM, (c), (r))))
#define term_cr()			(tputs_x(CR))
#define term_newline()			(tputs_x(NL))
#define	term_bold_on()			(tputs_x(MD))
#define	term_bold_off()			(tputs_x(ME))

	RETSIGTYPE 	term_cont 		(int);
	void 		term_beep 		(void);
	int		term_echo 		(int);
	int		term_init 		(void);
	int		term_resize 		(void);
	void		term_pause 		(char, char *);
	void		term_putchar 		(unsigned char);
	int		(*term_scroll) 		(int, int, int);
	int		(*term_insert) 		(char);
	int		(*term_delete) 		(void);
	int		(*term_cursor_right) 	(void);
	int		(*term_cursor_left) 	(void);
	int		(*term_clear_to_eol) 	(void);
	void		term_space_erase 	(int);
	void		term_reset 		(void);
	int		term_eight_bit 		(void);
	void		set_term_eight_bit 	(int);

#endif /* _TERM_H_ */

==> epic4pre1.042.tar.gz: ircii-EPIC4pre1.042/include/term.h <==
/*
 * term.h: header file for term.c 
 *
 * Copyright 1990 Michael Sandrof
 * Copyright 1997 EPIC Software Labs
 * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
 */

#ifndef __term_h__
#define __term_h__

/* To get declaration of "current_screen" */
#include "screen.h"

extern	int	need_redraw;
extern	char	*CM, *DO, *CE, *CL, *CR, *NL, *SO, *SE, *US, 
		*UE, *MD, *ME, *BL, *MB;
extern	int	CO, LI, SG, KM;

/* 
 * This puts a character to the current target, whatever it is. 
 * All output everywhere should go thorugh this.
 * This does not mangle its output, so its suitable for outputting
 * escape sequences.
 */
#if !defined(WTERM_C) && !defined(WSERV_C)
#define current_ftarget (output_screen ? output_screen->fpout : stdout)

__inline__ 
static int putchar_x (int c) { return fputc((int) c, current_ftarget); }

__inline__
static void term_flush (void) { fflush(current_ftarget); }
#endif


#define tputs_x(s)			(tputs(s, 0, putchar_x))
#define term_underline_on()		(tputs_x(US))
#define term_underline_off()		(tputs_x(UE))
#define term_standout_on()		(tputs_x(SO))
#define term_standout_off()		(tputs_x(SE))
#define term_blink_on()			(tputs_x(MB))
#define term_clear_screen()		(tputs_x(CL))
#define term_move_cursor(c, r)		(tputs_x(tgoto(CM, (c), (r))))
#define term_cr()			(tputs_x(CR))
#define term_newline()			(tputs_x(NL))
#define	term_bold_on()			(tputs_x(MD))
#define	term_bold_off()			(tputs_x(ME))

	RETSIGTYPE 	term_cont 		(int);
	void 		term_beep 		(void);
	int		term_echo 		(int);
	int		term_init 		(void);
	int		term_resize 		(void);
	void		term_pause 		(char, char *);
	void		term_putchar 		(unsigned char);
extern	int		(*term_scroll) 		(int, int, int);
extern	int		(*term_insert) 		(char);
extern	int		(*term_delete) 		(void);
extern	int		(*term_cursor_right) 	(void);
extern	int		(*term_cursor_left) 	(void);
extern	int		(*term_clear_to_eol) 	(void);
	void		term_space_erase 	(int);
	void		term_reset 		(void);
	int		term_eight_bit 		(void);
	void		set_term_eight_bit 	(int);

#endif /* _TERM_H_ */
